OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Mesaj atașat %s",
    "Important mail" : "Mail important",
    "No message found yet" : "Niciun mesaj încă",
    "Set up an account" : "Configurați un cont",
    "Unread mail" : "Mail necitit",
    "Important" : "Important",
    "Work" : "Lucru",
    "Personal" : "Personal",
    "To Do" : "De Făcut",
    "Later" : "Mai târziu",
    "Mail" : "Mail",
    "You are reaching your mailbox quota limit for {account_email}" : "Ați atins limita alocată pentru căsuța de mail {account_email}",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Utilizați {percentage} din spațiul alocat pentru mail. Puteți elibera spațiu prin eliminarea emailurilor care nu sunt necesare.",
    "Mails" : "Mailuri",
    "💌 A mail app for Nextcloud" : "💌 O aplicație de mail pentru Nextcloud",
    "Your session has expired. The page will be reloaded." : "Sesiunea a expirat. Pagina se va reîncărca.",
    "Drafts are saved in:" : "Mesajele nefinalizate sunt salvate în:",
    "Sent messages are saved in:" : "Mesajele trimise sunt salvate în:",
    "Deleted messages are moved in:" : "Mesajele șterse sunt salvate în:",
    "Archived messages are moved in:" : "Mesajele arhivate sunt mutate în:",
    "Snoozed messages are moved in:" : "Mesajele amânate sunt mutate în:",
    "Junk messages are saved in:" : "Mesajele nesolicitate sunt salvate în:",
    "Connecting" : "Se conectează",
    "Save" : "Salvează",
    "Connect" : "Conectare",
    "Looking up configuration" : "Se caută configurația",
    "Checking mail host connectivity" : "Se verifică conectivitatea cu serverul",
    "Configuration discovery failed. Please use the manual settings" : "Identificarea configurației a eșuat. Puteți utiliza configurarea manuală",
    "Password required" : "Parola este necesară",
    "Testing authentication" : "Se testează autentificarea",
    "Awaiting user consent" : "Se așteaptă confirmarea utilizatorului",
    "Account created. Please follow the pop-up instructions to link your Google account" : "Contul a fost creat. Urmați instrucțiunile pop-up pentru a conecta contul Google",
    "Loading account" : "Se încarcă contul",
    "Account updated" : "Contul a fost actualizat",
    "IMAP server is not reachable" : "Serverul IMAP nu poate fi contactat",
    "SMTP server is not reachable" : "Serverul SMTP nu poate fi contactat",
    "IMAP username or password is wrong" : "Parola sau numele utilizatorului pentru IMAP sunt eronate",
    "SMTP username or password is wrong" : "Parola sau numele utilizatorului pentru SMTP sunt eronate",
    "IMAP connection failed" : "Conectarea la IMAP a eșuat",
    "SMTP connection failed" : "Conectarea la SMTP a eșuat",
    "Authorization pop-up closed" : "Dialogul de autorizare s-a închis",
    "Configuration discovery temporarily not available. Please try again later." : "Descoperirea configurației este temporar indisponibilă. Încercați mai târziu.",
    "There was an error while setting up your account" : "A apărut o eroare la configurarea contului",
    "Auto" : "Auto",
    "Name" : "Nume",
    "Mail address" : "Adresă de mail",
    "name@example.org" : "name@example.org",
    "Please enter an email of the format name@example.com" : "Introduceți un email de forma name@example.com",
    "Password" : "Parolă",
    "Manual" : "Manual",
    "IMAP Settings" : "Setări IMAP",
    "IMAP Host" : "Host IMAP",
    "IMAP Security" : "Securitate IMAP",
    "None" : "Niciuna",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Port IMAP",
    "IMAP User" : "Utilizator IMAP",
    "IMAP Password" : "Parolă IMAP",
    "SMTP Settings" : "Setări SMTP",
    "SMTP Host" : "Host SMTP",
    "SMTP Security" : "Securitate SMTP",
    "SMTP Port" : "Port SMTP",
    "SMTP User" : "Utilizator SMTP",
    "SMTP Password" : "Parolă SMTP",
    "Account settings" : "Setări cont",
    "Aliases" : "Aliasuri",
    "Signature" : "Semnătură",
    "A signature is added to the text of new messages and replies." : "O semnătură a fost adăugată la noile mesaje trimise și la răspunsuri.",
    "Writing mode" : "Mod de scriere",
    "Preferred writing mode for new messages and replies." : "Modul de scriere preferat pentru mesajele și răspunsurile noi.",
    "Default folders" : "Dosare implicite",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "Folderele pentru schițe, mesaje trimise, mesaje șterse, arhivate și mesaje nesolicitate.",
    "Automatic trash deletion" : "Golirea automată a coșului",
    "Days after which messages in Trash will automatically be deleted:" : "Număr de zile după care mesajele din coș sunt șterse automat:",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Răspuns automat la mesajele primite. Dacă cineva vă trimite câteva mesaje, acest răspuns automat va fi trimis cel mult o dată la 4 zile.",
    "Calendar settings" : "Setări calendar",
    "Filters" : "Filtre",
    "Mail server" : "Server mail",
    "Update alias" : "Actualizează aliasul",
    "Rename alias" : "Redenumește aliasul",
    "Show update alias form" : "Afișează forma de actualizare alias",
    "Delete alias" : "Șterge alias",
    "Go back" : "Înapoi",
    "Change name" : "Schimbă numele",
    "Email address" : "Email",
    "Add alias" : "Adaugă alias",
    "Create alias" : "Creează alias",
    "Cancel" : "Anulează",
    "Could not update preference" : "Preferințele nu au putut fi actualizate",
    "Mail settings" : "Setări Mail",
    "General" : "General",
    "Add mail account" : "Adaugă un cont de mail",
    "Appearance" : "Aspect",
    "List" : "Listă",
    "Newest first" : "Cel mai nou mai întâi",
    "Oldest first" : "Cel mai vechi mai întâi",
    "Shared with me" : "Partajat cu mine",
    "Privacy" : "Confidențialitate",
    "Security" : "Securitate",
    "Compose new message" : "Compuneți mesaje noi",
    "Newer message" : "Mesaj mai recent",
    "Older message" : "Mesaj mai vechi",
    "Toggle star" : "Comută stea",
    "Toggle unread" : "Comută necitit",
    "Archive" : "Arhivă",
    "Delete" : "Șterge",
    "Search" : "Caută",
    "Send" : "Trimite",
    "Refresh" : "Reîmprospătează",
    "About" : "Despre",
    "Ok" : "Ok",
    "No certificate" : "Niciun certificat",
    "Certificate updated" : "Certificatul a fost actualizat",
    "Could not update certificate" : "Nu s-a putut actualiza certificatul",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - Valabil până {expiryDate}",
    "Select an alias" : "Selectați un alias",
    "Update Certificate" : "Actualizează certificatul",
    "Send later" : "Trimite mai târziu",
    "Message {id} could not be found" : "Mesajul {id} nu a fost găsit",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Orice formatare existentă (îngroșat, italic, subliniat sau imagini inline) vor fi eliminate.",
    "Turn off formatting" : "Dezactivează formatarea",
    "Turn off and remove formatting" : "Dezactivează și elimină formatarea",
    "Keep formatting" : "Păstrează formatarea",
    "From" : "De la",
    "Select account" : "Selectează cont",
    "To" : "Către",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "Subiect",
    "This message came from a noreply address so your reply will probably not be read." : "Acest mesaj a sosit de la o adresă noreply, astfel că răspunsul tău s-ar putea să nu fie citit.",
    "The following recipients do not have a PGP key: {recipients}." : "Următorii destinatari nu au o cheie PGP: {recipients}.",
    "Error saving draft" : "Eroare la salvarea schiței",
    "Draft saved" : "Mesaj salvat",
    "Save draft" : "Salvează schița",
    "Discard & close draft" : "Renunță și închide mesajul",
    "Enable formatting" : "Permite formatarea",
    "Disable formatting" : "Dezactivează formatarea",
    "Upload attachment" : "Încarcă atașament",
    "Add attachment from Files" : "Atașează din Fișiere",
    "Request a read receipt" : "Solicită confirmare de citire",
    "Encrypt message with Mailvelope" : "Criptează mesajul cu Mailvelope",
    "Send now" : "Trimite acum",
    "Tomorrow morning" : "Maine dimineață",
    "Tomorrow afternoon" : "Maine după amiază",
    "Monday morning" : "Luni dimineață",
    "Custom date and time" : "Dată și oră personalizate",
    "Enter a date" : "Introdu data",
    "Choose" : "Alege",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Atașamentul depășește dimensiunea totală de  {size}. Partajați fișierul prin link.","Atașamentele depășesc dimensiunea totală de  {size}. Partajați fișierele prin link-uri.","Atașamentele depășesc dimensiunea totală de  {size}. Partajați fișierele prin link-uri."],
    "Choose a file to add as attachment" : "Selectați un fișier ca atașament",
    "Choose a file to share as a link" : "Selectați un fișier pentru partajare ca link",
    "_{count} attachment_::_{count} attachments_" : ["{count} atașament","{count} atașamente","{count} atașamente"],
    "Untitled message" : "Mesaj fără titlu",
    "Expand composer" : "Expandează mesajul",
    "Close composer" : "Închide mesajul",
    "Confirm" : "Confirmă",
    "Tag: {name} deleted" : "Eticheta: {name} a fost ștearsă",
    "An error occurred, unable to delete the tag." : "Eticheta nu a putut fi ștearsă.",
    "The tag will be deleted from all messages." : "Eticheta va fi ștearsă pentru toate mesajele.",
    "Plain text" : "Text simplu",
    "Rich text" : "Text formatat",
    "No messages" : "Niciun mesaj",
    "Blind copy recipients only" : "Doar destinatarii din copia blind",
    "No subject" : "Fără subiect",
    "Later today – {timeLocale}" : "Azi, mai târziu – {timeLocale}",
    "Set reminder for later today" : "Setează memo pentru azi, mai târziu",
    "Tomorrow – {timeLocale}" : "Mâine – {timeLocale}",
    "Set reminder for tomorrow" : "Setează memo pentru mâine",
    "This weekend – {timeLocale}" : "În acest weekend – {timeLocale}",
    "Set reminder for this weekend" : "Setează memo pentru acest weekend",
    "Next week – {timeLocale}" : "Săptămâna viitoare– {timeLocale}",
    "Set reminder for next week" : "Setează memo pentru săptămâna viitoare",
    "Could not delete message" : "Mesajul nu a putut fi șters",
    "Could not archive message" : "Mesajul nu s-a putut arhiva",
    "Thread was snoozed" : "Conversația a fost amânată",
    "Could not snooze thread" : "Nu s-a putut amâna conversația",
    "Thread was unsnoozed" : "Conversația a fost reluată",
    "Could not unsnooze thread" : "Nu s-a putut relua conversația",
    "Encrypted message" : "Mesaj criptat",
    "This message is unread" : "Mesaj necitit",
    "Unfavorite" : "Elimină favorit",
    "Favorite" : "Favorite",
    "Unread" : "Necitit",
    "Read" : "Citit",
    "Unimportant" : "Neimportant",
    "Mark not spam" : "Nu este spam",
    "Mark as spam" : "Este spam",
    "Edit tags" : "Modifică tag-urile",
    "Snooze" : "Amână",
    "Unsnooze" : "Reluare",
    "Move thread" : "Mută conversația",
    "Archive thread" : "Arhivează conversația",
    "Archive message" : "Arhivează mesajul",
    "Delete thread" : "Șterge conversația",
    "Delete message" : "Șterge mesajul",
    "More actions" : "Mai multe acțiuni",
    "Back" : "Înapoi",
    "Set custom snooze" : "Setare amânare particularizată",
    "Edit as new message" : "Editează ca mesaj nou",
    "Create task" : "Creează sarcină",
    "Download message" : "Descarcă mesajul",
    "Load more" : "Încarcă mai mult",
    "_Mark {number} read_::_Mark {number} read_" : ["Marchează {number} ca citit","Marchează {number} ca citite","Marchează {number} ca citite"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Marchează {number} ca necitit","Marchează {number} ca necitite","Marchează {number} ca necitite"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Marchează {number} ca important","Marchează {number} ca importante","Marchează {number} ca importante"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Marchează {number} ca neimportant","Marchează {number} ca neimportante","Marchează {number} ca neimportante"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Elimină de la favorite {number}","Elimină de la favorite {number}","Elimină de la favorite {number}"],
    "_Favorite {number}_::_Favorite {number}_" : ["Setează ca favorit {number}","Setează ca favorite {number}","Setează ca favorite {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["Deselectează {number}","Deselectează {number}","Deselectează {number}"],
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Marchează {number} ca spam","Marchează {number} ca spam","Marchează {number} ca spam"],
    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["Marchează {number} ca nefiind spam","Marchează {number} ca nefiind spam","Marchează {number} ca nefiind spam"],
    "_Edit tags for {number}_::_Edit tags for {number}_" : ["Editează eticheta pentru {number}","Editează etichetele pentru {number}","Editează etichetele pentru {number}"],
    "_Move {number} thread_::_Move {number} threads_" : ["Mută {number} conversație","Mută {number} conversații","Mută {number} conversații"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Redirecționează {number} ca atașament","Redirecționează {number} ca atașament","Redirecționează {number} ca atașament"],
    "Mark as unread" : "Marchează ca necitit",
    "Mark as read" : "Marchează ca citit",
    "Report this bug" : "Raportați acest incident",
    "Event created" : "Evenimentul a fost  creat",
    "Could not create event" : "Evenimentul nu a putut fi creat",
    "Create event" : "Creează eveniment",
    "All day" : "Toată ziua",
    "Attendees" : "Participanți",
    "Select calendar" : "Selectează calendarul",
    "Description" : "Descriere",
    "Create" : "Crează",
    "This event was updated" : "Evenimentul a fost actualizat",
    "{attendeeName} accepted your invitation" : "{attendeeName} a acceptat invitația",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} intenționează să accepte invitația",
    "{attendeeName} declined your invitation" : "{attendeeName} a declinat invitația",
    "{attendeeName} reacted to your invitation" : "{attendeeName} a reacționat la invitație",
    "Failed to save your participation status" : "Eroare la salvarea statusului participanților",
    "You accepted this invitation" : "Ați acceptat această invitație",
    "You tentatively accepted this invitation" : "Intenționați să acceptați această invitație",
    "You declined this invitation" : "Ați declinat această invitație",
    "You already reacted to this invitation" : "Ați reacționat deja la această invitație",
    "You have been invited to an event" : "Ați fost invitat la un eveniment",
    "This event was cancelled" : "Acest eveniment a fost anulat",
    "Save to" : "Salvează în",
    "Select" : "Select",
    "Comment" : "Comentariu",
    "Accept" : "Accept",
    "Decline" : "Refuză",
    "Tentatively accept" : "Intenție de acceptare",
    "More options" : "Mai multe opțiuni",
    "domain" : "domeniu",
    "Remove" : "Elimină",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Nu aveți permisiunea să mutați mesajul în folderul de arhivare și/sau șterge mesajul din folderul curent",
    "Today" : "Azi",
    "Choose target folder" : "Alege directorul destinație",
    "No more submailboxes in here" : "Nu mai sunt subfoldere",
    "Favorites" : "Favorite",
    "Important info" : "Informații importante",
    "Other" : "Altele",
    "Could not send mdn" : "Eroare la transmiterea mdn",
    "The sender of this message has asked to be notified when you read this message." : "Expeditorul acestui mesaj a solicitat să fie notificat de citirea mesajului.",
    "Notify the sender" : "Notifică expeditorul",
    "You sent a read confirmation to the sender of this message." : "Ați transmis o confirmare de citire expeditorului acestui mesaj.",
    "Message was snoozed" : "Mesajul a fost amânat",
    "Could not snooze message" : "Nu s-a putut amâna mesajul",
    "Message was unsnoozed" : "Mesajul a fost reluat",
    "Could not unsnooze message" : "Nu s-a putut relua mesajul",
    "Forward" : "Înainte",
    "Move message" : "Mută mesajul",
    "Translate" : "Tradu",
    "Forward message as attachment" : "Transmite mesajul ca atașament",
    "View source" : "Sursa mesajului",
    "Download thread data for debugging" : "Descarcă datele conversației pentru debug",
    "Message body" : "Textul mesajului",
    "Unnamed" : "Fără nume",
    "Embedded message" : "Mesaj încorporat",
    "calendar imported" : "calendar importat",
    "Choose a folder to store the attachment in" : "Alege un dosar în care să stochez atașamentul",
    "Import into calendar" : "Importă în calendar",
    "Download attachment" : "Descarcă atașament",
    "Save to Files" : "Salvează în Fișiere",
    "View fewer attachments" : "Arată mai puține atașamente",
    "Choose a folder to store the attachments in" : "Selectați un folder pentru atașamente",
    "Save all to Files" : "Salvează tot în Fișiere",
    "Download Zip" : "Descarcă Zip",
    "_View {count} more attachment_::_View {count} more attachments_" : ["Afișează încă {count} atașament","Afișează încă {count} atașamente","Afișează încă {count} atașamente"],
    "The images have been blocked to protect your privacy." : "Imaginile au fost blocate pentru confidențialitate.",
    "Show images" : "Afișează imaginile",
    "Show images temporarily" : "Afișează temporar imaginile",
    "Always show images from {sender}" : "Afișează întotdeauna imaginile de la {sender}",
    "Always show images from {domain}" : "Afișează întotdeauna imaginile de la {domain}",
    "Message frame" : "Cadrul mesajului",
    "Quoted text" : "Text citat",
    "Move" : "Mută",
    "Moving" : "Se mută",
    "Moving thread" : "Mută conversația",
    "Moving message" : "Se mută mesajul",
    "Remove account" : "Sterge contul",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Contul pentru {email} și datele din cache vor fi eliminate din Nextcloud, dar nu și de la providerul de mail.",
    "Remove {email}" : "Șterge {email}",
    "Provisioned account is disabled" : "Contul configurat este dezactivat",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Logați-vă cu o parolă pentru a activa acest cont. Sesiunea curentă utilizează autentificarea fără parolă, de ex. SSO sau WebAuthn.",
    "Folder name" : "Denumire director",
    "Saving" : "Se salvează",
    "Move up" : "Mută înainte",
    "Move down" : "Mută în jos",
    "Show all folders" : "Arată toate directoarele",
    "_{total} message_::_{total} messages_" : ["{total} mesaj","{total} mesaje","{total} mesaje"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} necitit din {total}","{unread} necitite din {total}","{unread} necitite din {total}"],
    "All messages in mailbox will be deleted." : "Vor fi șterse toate mesajele din acest folder",
    "Clear mailbox {name}" : "Golește folderul {name}",
    "An error occurred, unable to rename the mailbox." : "Eroare la redenumirea mailbox.",
    "Mark all as read" : "Marcaţi tot ca fiind citit",
    "Rename" : "Redenumire",
    "Clear cache" : "Șterge cache",
    "Clear locally cached data, in case there are issues with synchronization." : "Ștergeți datele din cache local în cazul problemelor de sincronizare.",
    "Subscribed" : "Abonat",
    "Sync in background" : "Sincronizează în fundal",
    "New message" : "Mesaj nou",
    "Edit message" : "Editare mesaj",
    "Draft" : "Schiță",
    "Reply" : "Răspunde",
    "Message saved" : "Mesaj salvat",
    "Failed to save message" : "Eroare la salvarea mesajului",
    "Failed to save draft" : "Eroare la salvarea schiței",
    "attachment" : "atașament",
    "attached" : "atașat",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Încercați să trimiteți la prea mulți destinatari la Către și/sau Cc. încercați să folosiți Bcc pentru ascunderea adreselor destinatarilor.",
    "You mentioned an attachment. Did you forget to add it?" : "Ați menționat un atașament. Ați uitat cumva să-l adăugați?",
    "Message discarded" : "Mesaj eliminat",
    "Could not discard message" : "Nu s-a putut elimina mesajul",
    "Minimize composer" : "Minimizează editorul",
    "Error sending your message" : "Eroare la transmiterea mesajului",
    "Retry" : "Reîncearcă",
    "Warning sending your message" : "Avertizare la transmiterea mesajului",
    "Send anyway" : "Trimite oricum",
    "Autoresponder off" : "Autoresponder oprit",
    "Autoresponder on" : "Autoresponder activ",
    "Autoresponder follows system settings" : "Autoresponder-ul urmează setările sistemului",
    "The autoresponder follows your personal absence period settings." : "Autoresponder-ul urmărește setările perioadei de absență.",
    "Edit absence settings" : "Editați setările pentru absență",
    "First day" : "Prima zi",
    "Last day (optional)" : "Ultima zi (opțional)",
    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} va fi înlocuit cu subiectul mesajului la care răspundeți",
    "Message" : "Mesaj",
    "Save autoresponder" : "Salvează autoresponder",
    "Could not open outbox" : "Nu s-a putut deschide Outbox",
    "Pending or not sent messages will show up here" : "Mesajele în așteptare sau netransmise vor fi afișate aici",
    "Message could not be sent" : "Mesajul nu s-a putut transmite",
    "Message deleted" : "Mesajul a fost șters",
    "Copied email address to clipboard" : "Adresa de mail a fost copiată",
    "Could not copy email address to clipboard" : "Nu s-a putut copia adresa de mail",
    "Contacts with this address" : "Contacte cu această adresă",
    "Add to Contact" : "Adaugă la Contacte",
    "New Contact" : "Persoană de contact nouă",
    "Copy to clipboard" : "Copiază în clipboard",
    "Add" : "Adaugă",
    "Clear" : "Șterge ",
    "Close" : "Închide",
    "Search parameters" : "Parametri de căutare",
    "Search subject" : "Caută subiect",
    "Body" : "Corp",
    "Search body" : "Caută conținut",
    "Date" : "Date",
    "Pick a start date" : "Selectați o dată de început",
    "Pick an end date" : "Selectați o dată de sfârșit",
    "Select senders" : "Selectează expeditorii",
    "Select recipients" : "Selectează recipienții",
    "Select CC recipients" : "Selectați destinatarii pentru CC",
    "Select BCC recipients" : "Selectați destinatarii pentru BCC",
    "Tags" : "Etichete",
    "Select tags" : "Selectează etichete",
    "Marked as" : "Marcat ca",
    "Has attachments" : "Are atașamente",
    "Enable mail body search" : "Activează căutarea în textul mesajelor",
    "Custom" : "Particularizat",
    "The syntax seems to be incorrect:" : "Sintaxa pare incorectă:",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Semnătura este mai mare de 2 MB. Aceasta poate afecta performanța editorului.",
    "Save signature" : "Salvează semnătura",
    "Place signature above quoted text" : "Plasează semnătura deasupra textului citat",
    "Message source" : "Sursa mesajului",
    "An error occurred, unable to rename the tag." : "Eroare la redenumirea etichetei.",
    "Edit name or color" : "Editează numele sau culoarea",
    "Delete tag" : "Șterge eticheta",
    "Set tag" : "Setează eticheta",
    "Unset tag" : "Deselectează eticheta",
    "Tag name is a hidden system tag" : "Numele este al unei etichete de sistem ascunsă",
    "Tag already exists" : "Eticheta deja există",
    "An error occurred, unable to create the tag." : "Eroare la crearea etichetei.",
    "Add default tags" : "Adaugă etichetele implicite",
    "Add tag" : "Adaugă etichetă",
    "Task created" : "Sarcina a fost creată",
    "Could not create task" : "Sarcina nu a putut fi creată",
    "No calendars with task list support" : "Nu există calendare cu suport pentru liste de sarcini",
    "Summarizing thread failed." : "Rezumatul conversației a eșuat.",
    "Could not load your message thread" : "Nu poate fi încărcată conversația",
    "The thread doesn't exist or has been deleted" : "Conversația nu există sau a fost ștearsă",
    "Loading thread" : "Se încarcă conversația",
    "Not found" : "Nu a fost găsit",
    "Encrypted & verified " : "Criptat și verificat",
    "Signature verified" : "Semnătură verificată",
    "Signature unverified " : "Semnătură neverificată",
    "Reply all" : "Răspunde tuturor",
    "Unsubscribe request sent" : "Cerere de dezabonare trimisă",
    "Could not unsubscribe from mailing list" : "A eșuat dezabonarea de la lista de distribuție",
    "Unsubscribe" : "Dezabonare",
    "Reply to sender only" : "Răspunde doar expeditorului",
    "Mark as unfavorite" : "Elimină de la favorite",
    "Mark as favorite" : "Marchează ca favorit",
    "Unsubscribe via link" : "Dezabonare prin link",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "Dezabonare va opri mesajele din lista de distribuție {sender}",
    "Send unsubscribe email" : "Trimite email de dezabonare",
    "Unsubscribe via email" : "Dezabonare prin email",
    "{name} Assistant" : "{name} Asistent",
    "Go to latest message" : "Salt la ultimul mesaj",
    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Dezactivați păstrarea în coș lăsând câmpul necompletat sau introducând 0. Vor fi procesate doar mailurile șterse după activarea păstrării în coș. ",
    "Could not remove trusted sender {sender}" : "Expeditorul de încredere {sender} nu poate fi șters",
    "No senders are trusted at the moment." : "Niciun expeditor de încredere în acest moment. ",
    "Untitled event" : "Eveniment fără titlu",
    "(organizer)" : "(organizator)",
    "Import into {calendar}" : "Importă în {calendar}",
    "Event imported into {calendar}" : "Eveniment importat în {calendar}",
    "Reservation {id}" : "Rezervare {id}",
    "Deleted" : "Șters",
    "Recipient" : "Destinatar",
    "Help" : "Ajutor",
    "Actions" : "Acțiuni",
    "delete" : "ștergere",
    "Edit" : "Editează",
    "Successfully updated config for \"{domain}\"" : "S-a actualizat configurația pentru \"{domain}\"",
    "Error saving config" : "Eroare la salvarea configurației",
    "Saved config for \"{domain}\"" : "A fost salvată configurația pentru \"{domain}\"",
    "Mail app" : "Aplicația Mail",
    "The mail app allows users to read mails on their IMAP accounts." : "Aplicația de mail permite utilizatorilor să citească mailurile din conturile lor IMAP.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Aici găsiți setările generale pentru instanță. Setările specifice pentru utilizator se găsesc în aplicație (în colțul din stânga, jos).",
    "Account provisioning" : "Alimentare cont",
    "Add new config" : "Adaugă o nouă configurație",
    "Allow additional mail accounts" : "Permite conturi de mail suplimentare",
    "Allow additional Mail accounts from User Settings" : "Permite conturi de mail suplimentare în setările utilizator",
    "Anti Spam Service" : "Serviciul anti-spam",
    "The original message will be attached as a \"message/rfc822\" attachment." : "Mesajul original va fi atașat ca atașament \"message/rfc822\".",
    "\"Mark as Spam\" Email Address" : "\"Marchează ca Spam\" adresa de Email",
    "\"Mark Not Junk\" Email Address" : "\"Marchează ca Not Junk\" adresa de Email ",
    "Reset" : "Resetare",
    "Client ID" : "ID client",
    "Client secret" : "Secret client",
    "Unlink" : "Deconectare",
    "User" : "Utilizator",
    "Host" : "Gazdă",
    "Port" : "Portul",
    "Use master password" : "Folosește master password",
    "LDAP aliases integration" : "Integrare aliasuri LDAP",
    "Enable LDAP aliases integration" : "Activează integrarea aliasurilor LDAP",
    "Save Config" : "Salvează configurația",
    "S/MIME certificates" : "Certificatele S/MIME",
    "Certificate name" : "Nume certificat",
    "E-mail address" : "Adresa de E-mail ",
    "Valid until" : "Valabil până la",
    "Delete certificate" : "Șterge certificatul",
    "Certificate" : "Certificat",
    "Submit" : "Trimite",
    "Guest" : "Invitat",
    "Group" : "Grup",
    "Shared" : "Partajat",
    "Shares" : "Partajări",
    "Account connected" : "Cont conectat",
    "You can close this window" : "Puteți închide fereastra",
    "Connect your mail account" : "Conectați-vă contul de mail",
    "To add a mail account, please contact your administrator." : "Pentru adăugarea unui cont de mail, contactați administratorul.",
    "All" : "Toate ",
    "Drafts" : "Schițe",
    "All inboxes" : "Toate inbox-urile",
    "Junk" : "Nesolicitate",
    "Sent" : "Trimise",
    "Trash" : "Șterse",
    "Error while sharing file" : "Eroare la partajarea fișierului",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mesaj nou \nde la {from}","%n mesaje noi \nde la {from}","%n mesaje noi \nde la {from}"],
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "Un mesaj este în progres. Toate modificările nesalvate se vor pierde dacă continuați!",
    "Discard changes" : "Anulează modificările",
    "Discard unsaved changes" : "Anulează modificările nesalvate",
    "Keep editing message" : "Continuă editarea mesajului",
    "Attachments were not copied. Please add them manually." : "Atașamentele nu au fost copiate. Adăugați-le manual.",
    "Could not create snooze mailbox" : "Nu s-a putut crea un folder pentru mesaje amânate",
    "Message sent" : "Mesajul a fost transmis",
    "Could not send message" : "Mesajul nu s-a putut transmite",
    "Could not load {tag}{name}{endtag}" : "Nu s-a putut încărca {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Eroare la încărcarea {tag}{name}{endtag}",
    "Could not load your message" : "Mesajul nu s-a putut încărca",
    "Could not load the desired message" : "Nu s-a putut încărca mesajul dorit",
    "Could not load the message" : "Nu s-a putut încărca mesajul",
    "Error loading message" : "Eroare la încărcarea mesajelor",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Mesajul va fi marcat automat ca important în funcție de mesajele cu care ați interacționat sau pe care le-ați marcat ca importante. La început ar trebui să setați manual importanța pentru antrenarea sistemului, dar aceasta se va îmbunătăți în timp.",
    "Last 7 days" : "Ultimele 7 zile"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
