OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Mensagem embebida %s",
    "Important mail" : "Mensagem importante",
    "Set up an account" : "Configurar uma conta",
    "Unread mail" : "Mensagem por ler",
    "Important" : "Importante",
    "Work" : "Profissional",
    "Personal" : "Pessoal",
    "To Do" : "A fazer",
    "Later" : "Mais tarde",
    "Mail" : "Correio",
    "Mails" : "Mensagens",
    "💌 A mail app for Nextcloud" : "Uma aplicação de correio eletrónico para Nextcloud",
    "Drafts are saved in:" : "Os rascunhos são guardados em:",
    "Sent messages are saved in:" : "As mensagens enviadas são guardadas em:",
    "Deleted messages are moved in:" : "Deleted messages are moved in:",
    "Connecting" : "A ligar",
    "Reconnect Google account" : "Religar conta Google",
    "Reconnect Microsoft account" : "Religar conta Microsoft",
    "Save" : "Guardar",
    "Connect" : "Ligar",
    "Password required" : "Necessário palavra-passe",
    "Auto" : "Auto",
    "Name" : "Nome",
    "Password" : "Palavra-passe",
    "Manual" : "Manual",
    "IMAP Settings" : "Definições IMAP",
    "IMAP Host" : "Anfitrião de IMAP",
    "IMAP Security" : "Segurança IMAP",
    "None" : "Nenhum",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porto IMAP",
    "IMAP User" : "Utilizador IMAP",
    "IMAP Password" : "Palavra-passe IMAP",
    "SMTP Settings" : "Definições SMTP",
    "SMTP Host" : "Anfitrião de SMTP",
    "SMTP Security" : "Segurança SMTP",
    "SMTP Port" : "Porto SMTP",
    "SMTP User" : "Utilizador SMTP",
    "SMTP Password" : "Palavra-passe SMTP",
    "Account settings" : "Definições da conta",
    "Signature" : "Assinatura",
    "A signature is added to the text of new messages and replies." : "A assinatura é adicionada ao texto das novas mensagens e respostas.",
    "Writing mode" : "Modo de escrita",
    "Preferred writing mode for new messages and replies." : "Modo de escrita pré definido para novas mensagens e respostas.",
    "Default folders" : "Pastas pré definidas",
    "Calendar settings" : "Configurações do calendário",
    "Filters" : "Filtros",
    "Mail server" : "Servidor de correio eletrónico",
    "Go back" : "Voltar",
    "Change name" : "Alterar nome",
    "Email address" : "Endereço de email",
    "Add alias" : "Adicionar alcunha",
    "Cancel" : "Cancelar",
    "Search the body of messages in priority Inbox" : "Pesquise o corpo das mensagens na Caixa de entrada prioritária.",
    "Highlight external addresses" : "Destacar endereços externos",
    "Mail settings" : "Definições de e-mail",
    "General" : "Geral",
    "Set as default mail app" : "Definir como aplicação de e-mail predefinida",
    "Add mail account" : "Adicionar conta de email",
    "Appearance" : "Aspeto",
    "Show all messages in thread" : "Mostrar todas as mensagens da conversa",
    "When off, only the selected message will be shown" : "Quando desativado, apenas a mensagem selecionada será apresentada.",
    "Layout" : "Esquema",
    "Vertical split" : "Divisão vertical",
    "Horizontal split" : "Divisão horizontal",
    "List" : "Lista",
    "Sorting" : "Ordenação",
    "Newest first" : "Recentes primeiro",
    "Oldest first" : "Antigos primeiro",
    "Avatars from Gravatar and favicons" : "Avatares do Gravatar e favicons",
    "Reply position" : "Posição de resposta",
    "Top" : "Topo",
    "Bottom" : "Fundo",
    "Text blocks" : "Blocos de texto",
    "Reusable pieces of text that can be inserted in messages" : "Excertos de texto reutilizáveis ​​que podem ser inseridos nas mensagens.",
    "New text block" : "Novo bloco de texto",
    "Shared with me" : "Partilhadas comigo",
    "Privacy" : "Privacidade",
    "Data collection" : "Recolha de dados",
    "Allow the app to collect and process data locally to adapt to your preferences" : "Permitir que a aplicação recolha e processe dados localmente para se adaptar às suas preferências.",
    "Always show images from" : "Mostrar sempre imagens de",
    "Security" : "Segurança",
    "Manage your internal addresses and domains to ensure recognized contacts stay unmarked" : "Faça a gestão dos seus endereços e domínios internos para garantir que os contactos reconhecidos permanecem sem marcação.",
    "Manage certificates" : "Gerir certificados",
    "Mailvelope" : "Mailvelope",
    "Mailvelope is enabled for the current domain." : "O Mailvelope está ativado para o domínio atual",
    "Install the browser extension" : "Instalar a extensão do browser",
    "Enable for the current domain" : "Ativar para o domínio atual",
    "Compose new message" : "Compor nova mensagem",
    "Newer message" : "Mensagem mais recente",
    "Older message" : "Mensagem mais antiga",
    "Toggle star" : "Alternar estrela",
    "Toggle unread" : "Alternar entre não lidos",
    "Archive" : "Arquivar",
    "Delete" : "Eliminar",
    "Search" : "Pesquisar",
    "Send" : "Enviar",
    "Refresh" : "Atualizar",
    "About" : "Sobre",
    "Acknowledgements" : "Reconhecimentos",
    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Esta aplicação inclui o CKEditor, um editor de código aberto. Copyright © Colaboradores do CKEditor. Licenciado sob a GPLv2.",
    "Ok" : "CONFIRMAR",
    "From" : "De",
    "Select account" : "Selecionar uma conta",
    "To" : "Para",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "Assunto",
    "Draft saved" : "Rascunho guardado",
    "Enable formatting" : "Ativar formatação",
    "Upload attachment" : "Carregar anexo",
    "Add attachment from Files" : "Adicionar anexo a partir dos ficheiros",
    "Request a read receipt" : "Solicitar um recibo de leitura",
    "Encrypt message with Mailvelope" : "Cifrar a mensagem com Mailvelope",
    "Choose" : "Escolher",
    "Choose a file to add as attachment" : "Escolha um ficheiro para adicionar como anexo",
    "Confirm" : "Confirmar",
    "Plain text" : "Texto simples",
    "No messages" : "Sem mensagens",
    "Could not delete message" : "Não foi possível apagar a mensagem",
    "Unfavorite" : "Não favorito",
    "Favorite" : "Favorito",
    "Read" : "Ler",
    "Mark as spam" : "Marcar como spam",
    "Edit tags" : "Editar etiquetas",
    "More actions" : "Mais ações",
    "Back" : "Anterior",
    "Edit as new message" : "Editar como nova mensagem",
    "Download message" : "Transferir mensagem",
    "Load more" : "Carregar mais",
    "_Edit tags for {number}_::_Edit tags for {number}_" : ["Editar etiquetas para {number}","Editar etiquetas para {number}","Editar etiquetas para {number}"],
    "Could not create event" : "Não foi possível criar o evento",
    "Create event" : "Criar evento",
    "All day" : "Todo o dia",
    "Attendees" : "Participantes",
    "Description" : "Descrição",
    "Create" : "Criar",
    "Select" : "Selecionar",
    "Comment" : "Comentário",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "individual" : "individual",
    "domain" : "domínio",
    "Remove" : "Remover",
    "Add internal address" : "Adicionar endereço interno",
    "Last hour" : "Ultima hora",
    "Today" : "Hoje",
    "Last week" : "Ultima semana",
    "Last month" : "Ultimo mês",
    "Choose target folder" : "Escolher pasta de destino",
    "Favorites" : "Favoritos",
    "Important info" : "Informação importante",
    "Other" : "Outro",
    "Notify the sender" : "Notificar o remetente",
    "Forward" : "Encaminhar",
    "Translate" : "Traduzir",
    "View source" : "Ver fonte",
    "Message body" : "Corpo da mensagem",
    "Unnamed" : "Sem nome",
    "Embedded message" : "Mensagem embebida",
    "Choose a folder to store the attachment in" : "Escolha uma pasta para guardar o anexo",
    "Import into calendar" : "Importar para o calendário",
    "Download attachment" : "Transferir anexo",
    "Save to Files" : "Guardar em Ficheiros",
    "Choose a folder to store the attachments in" : "Escolha uma pasta para armazenar anexos",
    "Save all to Files" : "Guardar todos em Ficheiros",
    "Download Zip" : "Transferir Zip",
    "The images have been blocked to protect your privacy." : "As imagens foram bloqueadas para proteger a sua privacidade.",
    "Show images" : "Mostrar imagens",
    "Show images temporarily" : "Mostrar imagens temporariamente",
    "Always show images from {sender}" : "Mostrar sempre as imagem de {sender}",
    "Always show images from {domain}" : "Mostrar sempre as imagem de {domain}",
    "Move" : "Mover",
    "Moving" : "A mover",
    "Remove account" : "Remover conta",
    "Remove {email}" : "Remover {email}",
    "Folder name" : "Nome da pasta",
    "Saving" : "A guardar",
    "Move up" : "Mover para cima",
    "Move down" : "Mover para baixo",
    "Show all folders" : "Mostrar todas as pastas",
    "Collapse folders" : "Ocultar pastas",
    "Delete folder" : "Apagar pasta",
    "Mark all as read" : "Marcar todas como lidas",
    "Rename" : "Renomear",
    "Clear cache" : "Limpar cache",
    "Clear locally cached data, in case there are issues with synchronization." : "Limpe a cache de dados local no caso de ter problemas com a sincronização.",
    "Subscribed" : "Subscrito",
    "New message" : "Nova mensagem",
    "Reply" : "Resposta",
    "Error sending your message" : "Erro ao enviar a sua mensagem",
    "Retry" : "Repetir",
    "Warning sending your message" : "Aviso ao enviar a sua mensagem",
    "Send anyway" : "Enviar de qualquer maneira",
    "First day" : "First day",
    "Message" : "Mensagem",
    "Contacts with this address" : "Contactos com este endereço",
    "Add to Contact" : "Adicionar aos contactos",
    "New Contact" : "Novo contacto",
    "Copy to clipboard" : "Copiar para área de transferência",
    "Add" : "Adicionar",
    "Show less" : "Mostrar menos",
    "Clear" : "Limpar",
    "Close" : "Fechar",
    "Body" : "Corpo",
    "Date" : "Data",
    "Tags" : "Etiquetas",
    "Select tags" : "Selecione etiquetas",
    "Custom" : "Personalizado",
    "Save signature" : "Guardar assinatura",
    "Message source" : "Fonte da mensagem",
    "Tag already exists" : "A etiqueta já existe",
    "Add default tags" : "Adicionar etiquetas padrão",
    "Not found" : "Não  encontrado",
    "Reply to sender only" : "Resposta apenas ao remetente",
    "No senders are trusted at the moment." : "Nenhum remetente é confiável no momento.",
    "Untitled event" : "Evento sem título",
    "Import into {calendar}" : "Importar para {calendar}",
    "Event imported into {calendar}" : "Evento importado para {calendar}",
    "Airplane" : "Avião",
    "Reservation {id}" : "Reserva {id}",
    "Train" : "Comboio",
    "Deleted" : "Eliminado",
    "Recipient" : "Destinatário",
    "Help" : "Ajuda",
    "contains" : "contém",
    "matches" : "corresponde",
    "Actions" : "Ações",
    "Priority" : "Prioridade",
    "Tag" : "Etiqueta",
    "delete" : "eliminar",
    "Edit" : "Editar",
    "Reset" : "Reiniciar",
    "Client ID" : "Id. de Cliente",
    "Client secret" : "Segredo de cliente",
    "Email: {email}" : "Email: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} em {host}:{port} ({ssl} encryption)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} em {host}:{port} ({ssl} encryption)",
    "IMAP" : "IMAP",
    "User" : "Utilizador",
    "Host" : "Anfitrião",
    "Port" : "Porta",
    "SMTP" : "SMTP",
    "Valid until" : "Válido até",
    "Certificate" : "Certificado",
    "Submit" : "Submeter",
    "No text blocks available" : "Não existem blocos de texto disponíveis.",
    "Guest" : "Convidado",
    "Group" : "Grupo",
    "Shared" : "Partilhados",
    "Shares" : "Partilhas",
    "Account connected" : "Conta ligada",
    "Connect your mail account" : "Ligue a sua conta de e-mail",
    "All" : "Todos",
    "Drafts" : "Rascunhos",
    "Priority inbox" : "Caixa de entrada prioritária",
    "All inboxes" : "Todas as caixas de entrada",
    "Inbox" : "Caixa de Entrada",
    "Junk" : "Lixo",
    "Sent" : "Enviada",
    "Trash" : "Reciclagem",
    "Error while sharing file" : "Erro ao partilhar ficheiro",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Could not load {tag}{name}{endtag}" : "Não foi possível carregar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Ocorreu um problema ao carregar {tag}{name}{endtag}",
    "Could not load your message" : "Não foi possível carregar a sua mensagem",
    "Could not load the desired message" : "Não foi possível carregar a mensagem escolhida",
    "Could not load the message" : "Não foi possível carregar a mensagem",
    "Error loading message" : "Erro ao carregar a mensagem",
    "Determine importance using machine learning" : "Determinar a importância usando aprendizagem de máquina",
    "Last 7 days" : "Últimos 7 dias"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
