OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Вметната порака %s",
    "Important mail" : "Важни пораки",
    "No message found yet" : "Не се пронајдени пораки",
    "Set up an account" : "Постави сметка",
    "Unread mail" : "Непрочитани пораки",
    "Important" : "Важно",
    "Work" : "Работа",
    "Personal" : "Лично",
    "To Do" : "За правење",
    "Later" : "Покасно",
    "Mail" : "Електронска пошта",
    "You are reaching your mailbox quota limit for {account_email}" : "Го достигнувате лимитот на квотата на вашето поштенско сандаче за {account_email}",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Во моментов користите {percentage} од складиштето на вашето поштенско сандаче. Направете простор со бришење на непотребните е-пораки.",
    "Mails" : "Е-пошта пораки",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following email: %3$s" : "Испраќачот: %1$s не е во адресарот, но името на испраќачот: %2$s е во адресарот со адресата: %3$s",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following emails: %3$s" : "Испраќачот: %1$s не е во адресарот, но името на испраќачот: %2$s е во адресарот со адресата: %3$s",
    "Sent date is in the future" : "Датумот на испраќање е во иднина",
    "💌 A mail app for Nextcloud" : "💌 Апликација за електронска пошта за Nextcloud",
    "Your session has expired. The page will be reloaded." : "Сесијата истече. Страната ќе биде повторно вчитана.",
    "Drafts are saved in:" : "Шаблоните се зачувани во:",
    "Sent messages are saved in:" : "Испратените пораки се зачувани во:",
    "Deleted messages are moved in:" : "Избришаните пораки се преместени во:",
    "Archived messages are moved in:" : "Архивираните пораки се преместени во:",
    "Connecting" : "Поврзување",
    "Reconnect Google account" : "Повторно поврзи се Google сметка",
    "Sign in with Google" : "Најави се со Google",
    "Save" : "Зачувај",
    "Connect" : "Поврзи се",
    "Looking up configuration" : "Побарување конфигурација",
    "Checking mail host connectivity" : "Проверка на врската со е-пошта серверот",
    "Configuration discovery failed. Please use the manual settings" : "Неуспешна детекција на конфигурација. Користете рачни поставки",
    "Password required" : "Потребна е лозинка",
    "Testing authentication" : "Тестирање на автентикација",
    "Loading account" : "Вчирување на сметка",
    "Account updated" : "Сметката е ажурирана",
    "IMAP server is not reachable" : "IMAP серверот не е достапен",
    "SMTP server is not reachable" : "SMTP серверот не е достапен",
    "IMAP username or password is wrong" : "IMAP лозинката или корисничкото име се грешни",
    "SMTP username or password is wrong" : "SMTP лозинката или корисничкото име се грешни",
    "IMAP connection failed" : "Неуспешна IMAP врска",
    "SMTP connection failed" : "Неуспешна SMTP врска",
    "There was an error while setting up your account" : "Настана грешка при поставување на вашата сметка",
    "Auto" : "Автоматски",
    "Name" : "Име",
    "Mail address" : "Адреса на е-пошта",
    "name@example.org" : "ime@primer.com.mk",
    "Please enter an email of the format name@example.com" : "Внесете е-пошта во формат ime@primer.com.mk",
    "Password" : "Лозинка",
    "Manual" : "Рачно",
    "IMAP Settings" : "IMAP параметри",
    "IMAP Host" : "IMAP сервер",
    "IMAP Security" : "IMAP безбедност",
    "None" : "Ништо",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP порта",
    "IMAP User" : "IMAP корисник",
    "IMAP Password" : "IMAP лозинка",
    "SMTP Settings" : "SMTP параметри",
    "SMTP Host" : "SMTP сервер",
    "SMTP Security" : "SMTP безбедност",
    "SMTP Port" : "SMTP порта",
    "SMTP User" : "SMTP корисник",
    "SMTP Password" : "SMTP лозинка",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "За да работи Google сметка, потребно е да активирате дво-факторна авторизација за Google и да генерирате лозинка за апликација.",
    "Account settings" : "Праметри за сметката",
    "Signature" : "Потпис",
    "A signature is added to the text of new messages and replies." : "Потписот ќе се додава на крајот од текстот на нови пораки и одговори.",
    "Writing mode" : "Режим на пишување",
    "Preferred writing mode for new messages and replies." : "Претпочитан режим на пишување за нови пораки и одговори.",
    "Default folders" : "Стандардни папки",
    "Automatic trash deletion" : "Автоматско бришење на корпата со отпадоци",
    "Days after which messages in Trash will automatically be deleted:" : "Денови по кои пораките во корпата автоматски ќе се избришат:",
    "Autoresponder" : "Автоматски одговор",
    "Calendar settings" : "Параметри за календар",
    "Filters" : "Филтри",
    "Mail server" : "Сервер за е-пошта",
    "Update alias" : "Ажурирај алијас",
    "Delete alias" : "Избриши алијас",
    "Go back" : "Назад",
    "Change name" : "Промени име",
    "Email address" : "Е-пошта адреси",
    "Add alias" : "Додади псевдоним",
    "Create alias" : "Креирај алијас",
    "Cancel" : "Откажи",
    "Activate" : "Активирај",
    "Could not update preference" : "Неможе да се ажурираат параметрите",
    "Mail settings" : "Параметри за е-пошта",
    "General" : "Општо",
    "Add mail account" : "Додади е-пошта сметка",
    "Appearance" : "Изглед",
    "Layout" : "Распоред",
    "Vertical split" : "Вертикална поделба",
    "Horizontal split" : "Хоризонтална поделба",
    "List" : "Листа",
    "Sorting" : "Сортирање",
    "Newest first" : "Новите прво",
    "Oldest first" : "Старите прво",
    "Privacy" : "Приватност",
    "Security" : "Безбедност",
    "Compose new message" : "Состави нова порака",
    "Newer message" : "Понови пораки",
    "Older message" : "Постари пораки",
    "Toggle star" : "Вклучи омилени",
    "Toggle unread" : "Вклучи непрочитани",
    "Archive" : "Архива",
    "Delete" : "Избриши",
    "Search" : "Барај",
    "Send" : "Прати",
    "Refresh" : "Освежи",
    "About" : "За",
    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Оваа апликација го вклучува CKEditor, уредник со отворен код. Copyright © CKEditor contributors. Лиценцирано под GPLv2.",
    "Ok" : "Во ред",
    "No certificate" : "Нема сертификат",
    "Certificate updated" : "Сертификатот е ажуриран",
    "Could not update certificate" : "Неможе да се ажурира сертификатот",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - Валиден до {expiryDate}",
    "Select an alias" : "Избери алијас",
    "Select certificates" : "Избери сертификати",
    "Update Certificate" : "Ажурирај сертификат",
    "Encrypt with S/MIME and send later" : "Шифрирај со S/MIME и испрати ја подоцна",
    "Encrypt with S/MIME and send" : "Шифрирај со S/MIME и испрати",
    "Encrypt with Mailvelope and send later" : "Шифрирај со Mailvelope и испрати ја подоцна",
    "Encrypt with Mailvelope and send" : "Шифрирај со Mailvelope и испрати",
    "Send later" : "Испрати покасно",
    "Message {id} could not be found" : "Пораката {id} не е пронајдена",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Сите постоечки форматирања (како пример: болд, потцртан текст, италик итн.) ќе бидат отстранети.",
    "Turn off formatting" : "Исклучи форматирање",
    "Turn off and remove formatting" : "Исклучи и отстрани форматирање",
    "Keep formatting" : "Зачувај го форматирањето",
    "From" : "Од",
    "Select account" : "Избете сметка",
    "To" : "До",
    "Select recipient" : "Избери примач",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "Наслов",
    "This message came from a noreply address so your reply will probably not be read." : "Оваа порака е испратена од адреса што е назначена без одговор, така што вашиот одговор веројатно нема да биде прочитан.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "Следниве примачи не поседуваат S/MIME сертификат: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "Следниве примачи не поседуваат PGP клуч: {recipients}.",
    "Error saving draft" : "Грешка при зачувување на шаблон",
    "Draft saved" : "Нацртот е зачуван",
    "Save draft" : "Зачувај примерок",
    "Discard & close draft" : "Отфрли & затвори примерок",
    "Enable formatting" : "Овозможи форматирање",
    "Disable formatting" : "Оневозможи форматирање",
    "Upload attachment" : "Прикачи прилог",
    "Add attachment from Files" : "Додади прилог од датотеките",
    "Request a read receipt" : "Побарај потврда за прочитана порака",
    "Sign message with S/MIME" : "Потпиши ја пораката со S/MIME",
    "Encrypt message with S/MIME" : "Шифрирај порака со S/MIME",
    "Encrypt message with Mailvelope" : "Шифрирај порака со Mailvelope",
    "Send now" : "Испрати сега",
    "Tomorrow morning" : "Утре сабајле",
    "Tomorrow afternoon" : "Утре попладне",
    "Monday morning" : "Понеделник наутро",
    "Custom date and time" : "Одреден датум и време",
    "Enter a date" : "Внеси датум",
    "Choose" : "Избери",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Прилогот ја надминува најголемата дозволена големина за прилози од {size}. Споделете го прилогот со линк.","Прилозите ја надминуваат најголемата дозволена големина за прилози од {size}. Споделете ги прилозите со линк."],
    "Choose a file to add as attachment" : "Избери датотека за да додадете прилог",
    "Choose a file to share as a link" : "Избери датотека за да се сподели како линк",
    "_{count} attachment_::_{count} attachments_" : ["{count} прилог","{count} прилози"],
    "Untitled message" : "Неименувана порака",
    "Confirm" : "Потврди",
    "Plain text" : "Обичен текст",
    "Rich text" : "Богат текст",
    "No messages in this folder" : "Нема пораки во оваа папка",
    "No messages" : "Нема пораки",
    "Blind copy recipients only" : "Само приматели на слепи копии",
    "No subject" : "Нема наслов",
    "Later today – {timeLocale}" : "Денес покасно – {timeLocale}",
    "Set reminder for later today" : "Постави потсетник за денес покасно",
    "Tomorrow – {timeLocale}" : "Утре – {timeLocale}",
    "Set reminder for tomorrow" : "Постави потсетник за утре",
    "This weekend – {timeLocale}" : "Овој викенд – {timeLocale}",
    "Set reminder for this weekend" : "Постави потсетник за овој викенд",
    "Next week – {timeLocale}" : "Следна недела – {timeLocale}",
    "Set reminder for next week" : "Постави потсетник за наредната недела",
    "Could not delete message" : "Неможе да се избрише пораката",
    "This message is unread" : "Оваа порака не е прочитана",
    "Unfavorite" : "Од-означи",
    "Favorite" : "Омилени",
    "Unread" : "Непрочитана",
    "Read" : "Прочитана",
    "Unimportant" : "Неважна",
    "Mark not spam" : "Од-означи СПАМ",
    "Mark as spam" : "Означи како СПАМ",
    "Edit tags" : "Удери ознаки",
    "Delete message" : "Избриши порака",
    "More actions" : "Повеќе акции",
    "Back" : "Назад",
    "Edit as new message" : "Измени како нова порака",
    "Create task" : "Креирај задача",
    "Download message" : "Преземи порака",
    "Load more" : "Вчитај повеќе",
    "_Mark {number} read_::_Mark {number} read_" : ["Означи {number} прочитана","Означи {number} прочитани"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Означи {number} непрочитана","Означи {number} непрочитани"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Означи {number} како важна","Означи {number} како важни"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Означи {number} како неважна","Означи {number} како неважни"],
    "_Unselect {number}_::_Unselect {number}_" : ["Од-означи {number}","Од-означи {number}"],
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Означи {number} како спам","Означи {number} како спам"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Препрати како {number} прилог","Препрати {number} како прилози"],
    "Mark as unread" : "Означи како непрочитано",
    "Mark as read" : "Означи како прочитано",
    "Mark as important" : "Ознали како важна",
    "Report this bug" : "Пријави грешка",
    "Event created" : "Создаден е настан",
    "Could not create event" : "Неможе да се креира настан",
    "Create event" : "Креирај настан",
    "All day" : "Цели денови",
    "Attendees" : "Присутни",
    "Select calendar" : "Избери календар",
    "Description" : "Опис",
    "Create" : "Креирај",
    "This event was updated" : "Овој настан беше ажуриран",
    "{attendeeName} accepted your invitation" : "{attendeeName} ја прифати вашата покана",
    "You have been invited to an event" : "Поканети сте на настан",
    "This event was cancelled" : "Овој настан беше откажан",
    "Save to" : "Зачувај во",
    "Select" : "Select",
    "Comment" : "Коментар",
    "Accept" : "Прифати",
    "Decline" : "Одбиј",
    "More options" : "Повеќе опции ",
    "Could not remove internal address {sender}" : "Неможе да се отстрани внатрешната адреса {sender}",
    "Could not add internal address {address}" : "Неможе да се додаде внатрешната адреса {address}",
    "individual" : "индивидуално",
    "domain" : "домен",
    "Remove" : "Отстрани ",
    "Add internal address" : "Додади внатрешна адреса",
    "Add internal email or domain" : "Додади внатрешна е-пошта или домен",
    "Itinerary for {type} is not supported yet" : "Итинерар за {type} сеуште не е поддржан",
    "Today" : "Денес",
    "Last week" : "Минатата недела",
    "Choose target folder" : "Избери папка",
    "No more submailboxes in here" : "Нема повеќе подсандачиња тука",
    "Favorites" : "Омилени",
    "Important info" : "Важна информација",
    "Other" : "Останато",
    "The sender of this message has asked to be notified when you read this message." : "Испраќачот на оваа порака посака да биде известен кога ќе ја прочитате оваа порака.",
    "Notify the sender" : "Извести го испраќачот",
    "You sent a read confirmation to the sender of this message." : "Испративте потврда до испраќачот дека е прочитана пораката.",
    "Forward" : "Препрати",
    "Move message" : "Премести порака",
    "Translate" : "Преведи",
    "Forward message as attachment" : "Препрати ја пораката како прилог",
    "View source" : "Погледни извор",
    "Download thread data for debugging" : "Преземи информации за развивачи",
    "Message body" : "Тело на пораката",
    "Unnamed" : "Неименувана",
    "Embedded message" : "Вградена порака",
    "Choose a folder to store the attachment in" : "Избери папка за зачувување на прилогот",
    "Import into calendar" : "Увези во календар",
    "Download attachment" : "Преземи прилог",
    "Save to Files" : "Зачувај во датотеките",
    "Choose a folder to store the attachments in" : "Избери папка за зачувување на прилозите",
    "Save all to Files" : "Зачувај ги сите во датотеките",
    "Download Zip" : "Преземи Zip",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Оваа порака е шифрирана со PGP. Инсталирај Mailvelope за да ја дешифрираш.",
    "The images have been blocked to protect your privacy." : "Сликите се блокирани за да ја заштитите вашата приватност.",
    "Show images" : "Прикажи слики",
    "Show images temporarily" : "Привремено прикажи слики",
    "Always show images from {sender}" : "Секогаш прикажувај фотографии од {sender}",
    "Always show images from {domain}" : "Секогаш прикажувај фотографии од {domain}",
    "Message frame" : "Порака рамка",
    "Quoted text" : "Цитиран текст",
    "Move" : "Премести",
    "Moving" : "Преместува",
    "Moving message" : "Преместување порака",
    "Used quota: {quota}% ({limit})" : "Искористен простор: {quota}% ({limit})",
    "Used quota: {quota}%" : "Искористен простор: {quota}%",
    "Remove account" : "Отстрани сметка",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Сметката за {email} и зачуваните податоци ќе бидат избришани, но нема да бидат избришани од провајдерот на електронската пошта.",
    "Remove {email}" : "Одстрани {email}",
    "Show only subscribed folders" : "Прикажи само претплатени папки",
    "Add folder" : "Додади папка",
    "Folder name" : "Име на папка",
    "Saving" : "Зачувува",
    "Move up" : "Помести горе",
    "Move down" : "Помести доле",
    "Show all subscribed folders" : "Прикажи ги сите претплатени папки",
    "Show all folders" : "Прикажи ги сите папки",
    "Collapse folders" : "Сокриј ги папките",
    "_{total} message_::_{total} messages_" : ["{total} порака","{total} пораки"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочитана од {total}","{unread} непрочитани од {total}"],
    "Loading …" : "Се вчитува …",
    "Clear mailbox {name}" : "Исчисти сандаче {name}",
    "The folder and all messages in it will be deleted." : "Папката и сите пораки во неа ќе бидат избришани.",
    "Delete folder" : "Избриши папка",
    "Delete folder {name}" : "Избриши папка {name}",
    "An error occurred, unable to rename the mailbox." : "Настана грешка, неможе да се промени името на сандачето.",
    "Please wait 10 minutes before repairing again" : "Почекајте 10 минути пред повторно да поправите",
    "Mark all as read" : "Означи ги сите како прочитани",
    "Add subfolder" : "Додади подпапка",
    "Rename" : "Преименувај",
    "Move folder" : "Премести папка",
    "Repair folder" : "Поправи папка",
    "Clear cache" : "Избриши го кешот",
    "Clear locally cached data, in case there are issues with synchronization." : "Исчистете ги локално зачуваните податоци, во случај да има проблеми со синхронизацијата.",
    "Subscribed" : "Претплатени",
    "Sync in background" : "Синхронизација во позадина",
    "Outbox" : "Излезно сандаче",
    "New message" : "Нова порака",
    "Edit message" : "Уреди порака",
    "Draft" : "Шаблон",
    "Reply" : "Одговор",
    "Message saved" : "Пораката е зачувана",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Се обидувате да испратите до многу примачи во До и/или Cc. Можете да користите Bcc за да ги скриете адресите на примачите.",
    "Message discarded" : "Пораката е отфрлена",
    "Could not discard message" : "Неможе да се отфрли порака",
    "Error sending your message" : "Грешка при испраќање на пораката",
    "Retry" : "Обидете се повторно",
    "Send anyway" : "Испрати секако",
    "Welcome to {productName} Mail" : "Добредојдовте во {productName} е-пошта",
    "Start writing a message by clicking below or select an existing message to display its contents" : "Започнете да пишувате порака со кликнување подолу или изберете постоечка порака за да ја прикажете нејзината содржина",
    "Autoresponder off" : "Исклучен автоматски одговор",
    "Autoresponder on" : "Вклучен автоматски одговор",
    "First day" : "Прв ден",
    "Last day (optional)" : "Последен ден (опционално)",
    "Message" : "Порака",
    "Save autoresponder" : "Зачувај автоматски одговор",
    "Could not open outbox" : "Неможе да се отвори излезното сандаче",
    "Pending or not sent messages will show up here" : "Овде се појавуваат пораките кој се на чекање или што не се испратени",
    "Message could not be sent" : "Пораката неможе да се испрати",
    "Message deleted" : "Пораката е избришана",
    "Contacts with this address" : "Контакти со оваа адреса",
    "Add to Contact" : "Додади во контакти",
    "New Contact" : "Нов контакт",
    "Copy to clipboard" : "Копирај во клипборд",
    "Add" : "Додади",
    "Show less" : "Помалку",
    "Show more" : "Прикажи повеќе",
    "Clear" : "Исчисти",
    "Close" : "Затвори",
    "Search parameters" : "Параметри за пребарување",
    "Date" : "Датум",
    "Pick a start date" : "Избери почетен датум",
    "Pick an end date" : "Избери краен датум",
    "Select senders" : "Избери испраќачи",
    "Select recipients" : "Избери примачи",
    "Select CC recipients" : "Избери CC примачи",
    "Select BCC recipients" : "Избери BCC примачи",
    "Tags" : "Ознаки",
    "Select tags" : "Избери ознаки",
    "Marked as" : "Означено како",
    "Has attachments" : "Има прилози",
    "Sieve Port" : "Sieve порта",
    "Custom" : "Прилагодено",
    "Sieve User" : "Sieve корисник",
    "Sieve Password" : "Sieve лозинка",
    "Save sieve settings" : "Зачувај sieve параметри",
    "Save sieve script" : "Зачувај sieve скрипта",
    "Save signature" : "Зачувај потпис",
    "Place signature above quoted text" : "Постави го потписот над цитираниот текст",
    "Message source" : "Извор на пораката",
    "An error occurred, unable to rename the tag." : "Настана грешка, неможе да се преименува ознака.",
    "Tag name is a hidden system tag" : "Името на ознаката е сокриена системска ознака",
    "Tag already exists" : "Тагот веќе постои",
    "An error occurred, unable to create the tag." : "Настана грешка, неможе да се креира ознака.",
    "Add default tags" : "Додади стандардни ознаки",
    "Add tag" : "Додади ознака",
    "Could not load your message thread" : "Неможат да се преземат информации за пораката",
    "Not found" : "Не е пронајдено",
    "Reply all" : "Одговори на сите",
    "Reply to sender only" : "Одговор само до испраќачот",
    "Mark as unfavorite" : "Од-означи омилена",
    "Mark as favorite" : "Означи како омилена",
    "Untitled event" : "Неименуван настан",
    "(organizer)" : "(organizer)",
    "Import into {calendar}" : "Увези во {calendar}",
    "Event imported into {calendar}" : "Настанот е увезен во {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Лет {flightNr} од {depAirport} до {arrAirport}",
    "Airplane" : "Авион",
    "Reservation {id}" : "Резервација {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} од {depStation} до {arrStation}",
    "Train from {depStation} to {arrStation}" : "Воз од  {depStation} до {arrStation}",
    "Train" : "Воз",
    "Deleted" : "Избришани",
    "Help" : "Помош",
    "matches" : "се совпаѓа",
    "Actions" : "Акции",
    "Priority" : "Приоритет",
    "delete" : "избриши",
    "Edit" : "Уреди",
    "Mail app" : "Апликација Електронска пошта",
    "The mail app allows users to read mails on their IMAP accounts." : "Апликацијата за електронска пошта дозволува на корисниците да ги читаат својте пораки од IMAP сметки.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Овде може да се пронајде поопшитно прилагодување. Специфични параметри за корисниците може да се пронајдат во самата апликација (доле-лево).",
    "Gmail integration" : "Gmail интеграција",
    "Microsoft integration" : "Microsoft интеграција",
    "Reset" : "Ресетирање",
    "Client ID" : "Клиент ИД",
    "Client secret" : "Тајна на клиент",
    "Domain Match: {provisioningDomain}" : "Софпаѓање на домен: {provisioningDomain}",
    "Email: {email}" : "Е-пошта: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} на {host}:{port} ({ssl} енкрипција)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} на {host}:{port} ({ssl} енкрипција)",
    "Configuration for \"{provisioningDomain}\"" : "Конфигурација за \"{provisioningDomain}\"",
    "IMAP" : "IMAP",
    "User" : "Корисник",
    "Host" : "Домаќин",
    "Port" : "Порта",
    "SMTP" : "SMTP",
    "Save Config" : "Зачувај конфигурација",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% и %EMAIL% ќе биде заменето со корнички ID и e-po[ta",
    "With the settings above, the app will create account settings in the following way:" : "Со овие параметри, апликацијата ќе креира сметки:",
    "Failed to import the certificate. Please check the password." : "Неуспешно увезување на сертификат. Проверете ја лозинката.",
    "Certificate imported successfully" : "Сертификатот е успешно увезен",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Неуспешно увезување на сертификат. Проверете дали приватниот клуч се совпаѓа со сертификатот и не е заштитен со лозинка.",
    "Failed to import the certificate" : "Неуспешен увоз на сертификат",
    "S/MIME certificates" : "S/MIME сертификати",
    "Certificate name" : "Име на сертификатот",
    "E-mail address" : "Е-пошта адреса",
    "Valid until" : "Валиден до",
    "Delete certificate" : "Избриши сертификат",
    "No certificate imported yet" : "Сеуште нема увезено сертификат",
    "Import certificate" : "Увези сертификат",
    "Import S/MIME certificate" : "Увези S/MIME сертификат",
    "PKCS #12 Certificate" : "PKCS #12 Сертификат",
    "PEM Certificate" : "PEM Сертификат",
    "Certificate" : "Сертификат",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Приватниот клуч е потребен само ако планирате да испраќате потпишани и шифрирани е-пораки користејќи го овој сертификат.",
    "Submit" : "Испрати",
    "Group" : "Група",
    "Shared" : "Споделено",
    "Shares" : "Споделувања",
    "Account connected" : "Сметката е поврзана",
    "You can close this window" : "Можете да го затворите овој прозорец",
    "Connect your mail account" : "Поврзете ја вашата е-пошта сметка",
    "All" : "Сите",
    "Drafts" : "Шаблони",
    "Priority inbox" : "Приоритетно сандаче",
    "All inboxes" : "Сите сандачиња",
    "Inbox" : "Сандаче",
    "Junk" : "Спам",
    "Sent" : "Испратени",
    "Trash" : "Корпа",
    "Error while sharing file" : "Грешка при споделување на датотека",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n нова порака \nод {from}","%n нови пораки\nод {from}"],
    "Nextcloud Mail" : "Електронска пошта",
    "Discard changes" : "Орфрли промени",
    "Discard unsaved changes" : "Отфрли ги назачуваните промени",
    "Keep editing message" : "Продолжи со уредување на порака",
    "Attachments were not copied. Please add them manually." : "Пролозите на се копирани. Додадете ги рачно.",
    "Sending message…" : "Испраќање на порака ...",
    "Message sent" : "Пораката е испратена",
    "Could not send message" : "Неможе да се испрати порака",
    "Could not load {tag}{name}{endtag}" : "Неможе да се вчита {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Има проблем со вчитување на {tag}{name}{endtag}",
    "Could not load your message" : "Неможе да се вчита пораката",
    "Could not load the desired message" : "Неможе да се вчита посакуваната порака",
    "Could not load the message" : "Неможе да се вчита пораката",
    "Error loading message" : "Грешка при вчитување на пораката",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Пораките автоматски ќе бидат означени како важни врз основа на кои пораки сте комуницирале или сте ги означиле како важни. На почетокот можеби ќе треба рачно да ја менувате важноста да го научите системот, но тоа ќе се подобрува со текот на времето.",
    "Mark all messages of this folder as read" : "Означи ги сите пораки во оваа папка како прочитани",
    "Last 7 days" : "Предходни 7 дена"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
